psychopy_ext.exp.make_para — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.exp.make_para

`psychopy_ext.exp.` `make_para`(n=6)

  Generates a symmetric para file with fixation periods approximately 25% of the time.

  Kwargs: | n (int, default: 6) Size of Latin square. Should be equal to the number of conditions you have. :note: n must be even. For an odd n, I am not aware of a general method to produce a Latin square.
  Returns: | A numpy.array with each row representing one possible ordering of stimuli (fixations are coded as 0).